@@ -26,7 +26,7 @@ if hasattr(gettext, 'bind_textdomain_codeset'):
     gettext.bind_textdomain_codeset('gwibber','UTF-8')
 gettext.textdomain('gwibber')
 
-import gtk
+from gi.repository import Gtk
 
 class GwibberErrorService:
 
@@ -63,18 +63,18 @@ class GwibberErrorService:
 
         self.notified[service] = type
         if condition == "info":
-            condition = gtk.MESSAGE_INFO
+            condition = Gtk.MessageType.INFO
         else:
-            condition = gtk.MESSAGE_ERROR
+            condition = Gtk.MessageType.ERROR
 
         if title is None:
             title = _("Gwibber Error")
-        dialog = gtk.MessageDialog(
+        dialog = Gtk.MessageDialog(
             parent = None,
             type = condition,
-            buttons = gtk.BUTTONS_CLOSE,
+            buttons = Gtk.ButtonsType.CLOSE,
             message_format = message)
         dialog.set_title(title)
-        dialog.set_position(gtk.WIN_POS_CENTER_ALWAYS)
+        dialog.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
         dialog.run()
         dialog.destroy()
