@@ -1,8 +1,11 @@
 from gwibber.microblog import network, util
-from gwibber.microblog.util import resources
 import json
 from oauth import oauth
 
+import logging
+logger = logging.getLogger("Buzz")
+logger.debug("Initializing.")
+
 PROTOCOL_INFO = {
   "name": "Buzz",
   "version": "1.0",
@@ -134,5 +137,3 @@ class Client:
     path = "activities/%s/@self/%s/@comments" % (target["sender"]["id"], target["mid"])
     self._get(path, post=True, single=True, body=text)
     return []
-
-
