@@ -18,23 +18,22 @@
 # Twitter widgets for Gwibber
 #
 
-import gtk
-from gtk import Builder
+from gi.repository import Gtk
 from gwibber.microblog.util import resources
 
-class AccountWidget(gtk.VBox):
+class AccountWidget(Gtk.VBox):
   """AccountWidget: A widget that provides a user interface for configuring qaiku accounts in Gwibber
   """
   
   def __init__(self, account=None, dialog=None):
     """Creates the account pane for configuring qaiku accounts"""
-    gtk.VBox.__init__( self, False, 20 )
-    self.ui = gtk.Builder()
+    Gtk.VBox.__init__( self, False, 20 )
+    self.ui = Gtk.Builder()
     self.ui.set_translation_domain ("gwibber")
     self.ui.add_from_file (resources.get_ui_asset("gwibber-accounts-qaiku.ui"))
     self.ui.connect_signals(self)
     self.vbox_settings = self.ui.get_object("vbox_settings")
-    self.pack_start(self.vbox_settings, False, False)
+    self.pack_start(self.vbox_settings, False, False, 0)
     self.show_all()
     if dialog.ui:
        dialog.ui.get_object("vbox_create").show()
