@@ -1,10 +1,11 @@
-
-import os, locale, re, mx.DateTime, cgi
-import log, resources
+import os, locale, re, mx.DateTime, cgi, httplib2
+import resources
 import dbus
 from const import *
 from htmlentitydefs import name2codepoint
 
+import logging
+logger = logging.getLogger("Microblog Util")
 
 # Try to import * from custom, install custom.py to include packaging 
 # customizations like distro API keys, etc
@@ -64,6 +65,37 @@ def linkify(text, subs=[], escape=True):
   return re.compile(r'"www.', re.U).sub('"http://www.', link)
 
 def imgpreview(text):
+  images = []
+  
+  # If the text is a direct link to a jpg
+  if text.endswith((".jpg", ".gif", ".png", ".bmp")):
+     images.append({"src": text, "url": None})
+     return images
+  
+  # For pic.twitter.com images not wrapped in media entities
+  if "pic.twitter.com" in text:
+    # Annoyingly, we have to scrape the page of the tweet to get the actual image location
+    # The mobile site has smaller pages, so we'll use that
+    page = text.replace("/photo/1", "")
+    page = thumb.replace("http://", "http://mobile.")
+
+    resp, content = httplib2.Http().request(page)
+    start = content.index("http://p.twimg.com")
+    end = content.index(':small"><img') + 6
+
+    image = content[start:end]
+    images.append({"src": image, "url": None})
+    return images
+
+  if "instagr.am" in text:
+    # The location of the image is hidden in the header of the short link
+    thumb = text + "media?/size=m"
+    resp, content = httplib2.Http().request(thumb)
+    thumb = resp["content-location"]
+    
+    images.append({"src": thumb, "url": None})
+    return images
+  
   thumbre = {
     'twitpic': 'http://.*twitpic.com/(?!photos)([A-Za-z0-9]+)',
     'img.gd': 'http://img.gd/(?!photos)([A-Za-z0-9]+)',
@@ -71,12 +103,10 @@ def imgpreview(text):
     'twitgoo': 'http://.*twitgoo.com/(?!u/)([A-Za-z0-9]+)',
     'yfrog.us': 'http://.*yfrog.us/(?!froggy)([A-Za-z0-9]+)',
     'yfrog.com': 'http://.*yfrog.com/(?!froggy)([A-Za-z0-9]+)',
-    'twitvid': 'http://.*twitvid.com/(?!videos)([A-Za-z0-9]+)',
     'img.ly': 'http://img.ly/(?!images)([A-Za-z0-9]+)', 
     'flic.kr': 'http://flic.kr/p/([A-Za-z0-9]+)',
-    'youtu.be': 'http://youtu.be/([A-Za-z0-9-_]+)',
-    'youtube.com': 'http://.*youtube.com/watch\?v=([A-Za-z0-9-_]+)',
-    'tweetphoto': 'http://.*tweetphoto.com/(0-9]+)',
+    'tweetphoto': 'http://.*tweetphoto.com/([0-9]+)',
+    'plixi': 'http://plixi.com/p/([0-9]+)',
     'pic.gd': 'http://pic.gd/([A-Za-z0-9]+)',
     'brizzly': 'http://.*brizzly.com/pic/([A-Za-z0-9]+)',
     'twitxr': 'http://.*twitxr.com\/[^ ]+\/updates\/([0-9]+)',
@@ -88,22 +118,19 @@ def imgpreview(text):
     'moby.to': 'http://moby.to/([A-Za-z0-9]+)',
     'movapic': 'http://.*movapic.com/pic/([A-Za-z0-9]+)',
     'znl.me': 'http://znl.me/([A-Za-z0-9-_]+)',
-    'bcphotoshare': 'http://.*bcphotoshare.com/photos/[0-9]+/([0-9]+)',
-    'twitvideo.jp': 'http://.*twitvideo.jp/(?!contents)([A-Za-z0-9-_]+)'
+    'bcphotoshare': 'http://.*bcphotoshare.com/photos/[0-9]+/([0-9]+)'
     }
   thumburi = {
     'twitpic': 'http://twitpic.com/show/thumb/@',
     'img.gd': 'http://img.gd/show/thumb/@',
     'imgur': 'http://i.imgur.com/@s.jpg',
     'twitgoo': 'http://twitgoo.com/show/thumb/@',
-    'yfrog.us': 'http://yfrog.us/@.th.jpg',
-    'yfrog.com': 'http://yfrog.com/@.th.jpg',
-    'twitvid': 'http://images.twitvid.com/@.jpg',
+    'yfrog.us': 'http://yfrog.us/@:iphone',
+    'yfrog.com': 'http://yfrog.com/@:iphone',
     'img.ly': 'http://img.ly/show/thumb/@',
     'flic.kr': 'http://flic.kr/p/img/@_m.jpg',
-    'youtu.be': 'http://img.youtube.com/vi/@/default.jpg',
-    'youtube.com': 'http://img.youtube.com/vi/@/default.jpg',
     'tweetphoto': 'http://TweetPhotoAPI.com/api/TPAPI.svc/json/imagefromurl?size=thumbnail&url=@',
+    'plixi': 'http://api.plixi.com/api/tpapi.svc/imagefromurl?size=thumbnail&url=@',
     'pic.gd': 'http://TweetPhotoAPI.com/api/TPAPI.svc/json/imagefromurl?size=thumbnail&url=@',
     'brizzly': 'http://pics.brizzly.com/thumb_sm_@.jpg',
     'twitxr': 'http://twitxr.com/image/@/th/',
@@ -115,19 +142,45 @@ def imgpreview(text):
     'moby.to': 'http://api.mobypicture.com?s=small&format=plain&k=6JQhCKX6Z9h2m9Lo&t=@',
     'movapic': 'http://image.movapic.com/pic/s_@.jpeg',
     'znl.me': 'http://app.zannel.com/content/@/Image-160x120-P-JPG.jpg',
-    'bcphotoshare': 'http://images.bcphotoshare.com/storages/@/thumbnail.jpg',
-    'twitvideo.jp': 'http://twitvideo.jp/img/thumb/@'
+    'bcphotoshare': 'http://images.bcphotoshare.com/storages/@/thumbnail.jpg'
     }
 
-  images = []
+
   for r, u in zip(thumbre, thumburi):
     for match in re.finditer(thumbre[r], text):
       if r == 'tweetphoto' or r == 'pic.gd' or r == 'moby.to':
-        images.append({"src": thumburi[u].replace('@', match.group(0)) , "url": match.group(0)})
+        images.append({"src": thumburi[u].replace('@', match.group(0)) , "url": None})
       else:
-        images.append({"src": thumburi[u].replace('@', match.group(1)) , "url": match.group(0)})
+        images.append({"src": thumburi[u].replace('@', match.group(1)) , "url": None})
   return images
 
+def videopreview(text):
+  videos = []
+
+  thumbre = {
+    'twitvid': 'http://.*twitvid.com/(?!videos)([A-Za-z0-9]+)',
+    'youtu.be': 'http://youtu.be/([A-Za-z0-9-_]+)',
+    'youtube.com': 'http://.*youtube.com/watch\?v=([A-Za-z0-9-_]+)',
+    'twitvideo.jp': 'http://.*twitvideo.jp/(?!contents)([A-Za-z0-9-_]+)'
+    }
+  thumburi = {
+    'twitvid': 'http://images.twitvid.com/@.jpg',
+    'youtu.be': 'http://img.youtube.com/vi/@/0.jpg',
+    'youtube.com': 'http://img.youtube.com/vi/@/0.jpg',
+    'twitvideo.jp': 'http://twitvideo.jp/img/thumb/@'
+    }
+  thumbvid = {
+    'twitvid': 'http://.*twitvid.com/@',
+    'youtu.be': 'http://www.youtube.com/watch?v=@',
+    'youtube.com': 'http://www.youtube.com/watch?v=@',
+    'twitvideo.jp': 'http://www.twitvideo.jp/@'
+    }
+    
+  for r, u in zip(thumbre, thumburi):
+    for match in re.finditer(thumbre[r], text):
+      videos.append({ "src": thumburi[u].replace('@', match.group(1)), "url"       : text})
+  return videos
+
 def compact(data):
   if isinstance(data, dict):
     return dict([(x, y) for x,y in data.items() if y])
@@ -163,35 +216,43 @@ def isRTL(s):
 	return False
 
 try:
-  import pynotify
-  import gtk, gtk.gdk, glib
-  pynotify.init("Gwibber")
+  from gi.repository import GdkPixbuf, GLib, Notify
+  Notify.init("Gwibber")
 
   def notify(title, text, icon = None, timeout = None, iconsize = 48):
     if icon is None:
-      icon = resources.get_ui_asset("gwibber.svg")
-    
-    caps = pynotify.get_server_caps()
-    
-    notification = pynotify.Notification(title, text)
+      icon = resources.get_ui_asset("icons/hicolor/scalable/apps/gwibber.svg")
 
+    if icon is None:
+      return
+    
+    caps = Notify.get_server_caps()
+    
+    notification = Notify.Notification.new(title, text, "gwibber")
+
+    pixbuf = None
     try:
-      pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(icon, iconsize, iconsize)
-      notification.set_icon_from_pixbuf(pixbuf)
-    except glib.GError as e:
-      log.logger.error("Avatar failure - %s - %s", icon, e.message)
+      pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(icon, iconsize, iconsize)
+    except GLib.Error as e:
+      logger.error("Avatar failure - %s - %s", icon, e.message)
       resources.del_avatar(icon)
 
+    if pixbuf:
+      try:
+        notification.set_icon_from_pixbuf(pixbuf)
+      except GLib.Error as e:
+        logger.error("Notification failure - %s", e.message)
+
     if timeout:
       notification.set_timeout(timeout)
 
     if "x-canonical-append" in caps:
-      notification.set_hint('x-canonical-append', 'allowed')
+      notification.set_hint_string('x-canonical-append', 'allowed')
 
     try:
       notification.show ()
     except:
-      log.logger.error("Notification failed")
+      logger.error("Notification failed")
     return
 
   can_notify = True
